SchemaSpy - gnss_data.public - Constraints

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

SchemaSpy Analysis of gnss_data.public - Constraints | Generated by SchemaSpy

14 Foreign Key Constraints: |

Constraint Name | Child Column | Parent Column | Delete Rule
--- | --- | --- | ---
apr_coords_NetworkCode_fkey | apr_coords.NetworkCode apr_coords.StationCode | stations.NetworkCode stations.StationCode | Restrict delete
gamit_soln_NetworkCode_fkey | gamit_soln.NetworkCode gamit_soln.StationCode | stations.NetworkCode stations.StationCode | Restrict delete
gamit_soln_NetworkCode_fkey1 | gamit_soln.NetworkCode gamit_soln.StationCode gamit_soln.Year gamit_soln.DOY | rinex.NetworkCode rinex.StationCode rinex.ObservationYear rinex.ObservationDOY | Restrict delete
locks_NetworkCode_fkey | locks.NetworkCode locks.StationCode | stations.NetworkCode stations.StationCode | Cascade on delete
NetworkCode | stations.NetworkCode | networks.NetworkCode | Restrict delete
ppp_soln_excl_NetworkCode_fkey | ppp_soln_excl.NetworkCode ppp_soln_excl.StationCode | stations.NetworkCode stations.StationCode | Restrict delete
ppp_soln_NetworkCode_fkey | ppp_soln.NetworkCode ppp_soln.StationCode ppp_soln.Year ppp_soln.DOY | rinex.NetworkCode rinex.StationCode rinex.ObservationYear rinex.ObservationDOY | Restrict delete
ppp_soln_NetworkName_StationCode_fkey | ppp_soln.NetworkCode ppp_soln.StationCode | stations.NetworkCode stations.StationCode | Restrict delete
rinex_extra_NetworkCode_fkey | rinex_extra.NetworkCode rinex_extra.StationCode | stations.NetworkCode stations.StationCode | Restrict delete
rinex_NetworkCode_fkey | rinex.NetworkCode rinex.StationCode | stations.NetworkCode stations.StationCode | Restrict delete
rinex_tank_struct_key_fkey | rinex_tank_struct.KeyCode | keys.KeyCode | Restrict delete
stationinfo_AntennaCode_fkey | stationinfo.AntennaCode | antennas.AntennaCode | Restrict delete
stationinfo_NetworkCode_StationCode_fkey | stationinfo.NetworkCode stationinfo.StationCode | stations.NetworkCode stations.StationCode | Restrict delete
stationinfo_ReceiverCode_fkey | stationinfo.ReceiverCode | receivers.ReceiverCode | Restrict delete

Check Constraints:

Table | Constraint Name | Constraint
--- | --- | ---
None detected